Learn R Programming

eqs2lavaan (version 3.0)

eqs2lavaan-package: EQS Output Conversion to lavaan Functions

Description

Transitioning from EQS to R for structural equation modeling (SEM) is made easier with a set of functions to convert .out files into R code. The EQS output can be converted into lavaan syntax and run in the R environment. Other functions parse descriptive statistics and the covariance matrix from an EQS .out file. A heat map plot of a covariance matrix is also included.

Arguments

Details

Package:
eqs2lavaan
Type:
Package
Version:
1.0
Date:
2013-07-25
License:
GPL-2

References

Bentler, P. M. (2008). EQS Program Manual. Encino, CA: Multivariate Software Inc.

Rosseel, Yves (2012). lavaan: An R Package for Structural Equation Modeling. Journal of Statistical Software, 48(2), 1-36. http://www.jstatsoft.org/v48/i02/.