Learn R Programming

eqs2lavaan (version 3.0)

eqsCorr: Translate Covariance Matrix in EQS Output to a Correlation Matrix in R

Description

The EQS .out file contains all the necessary information to return a correlation matrix. This function allows you to extract the necessary info and save the correlation matrix for your own use in R.

Usage

eqsCorr(eqs)

Arguments

eqs
A valid unedited .out file from EQS output.

Value

A correlation matrix.

References

Bentler, P. M. (2008). EQS Program Manual. Encino, CA: Multivariate Software Inc.

Yves Rosseel (2012). lavaan: An R Package for Structural Equation Modeling. Journal of Statistical Software, 48(2), 1-36. URL http://www.jstatsoft.org/v48/i02/.

See Also

plotCov eqsCorr eqsDesc eqs2lavaan

Examples

Run this code
# EQS required to get a necessary .out file
# Run for62.eqs from the EQS examples and save .out to R directory location

## Not run: eqsCorr("for62.out")

Run the code above in your browser using DataLab