out2lavaan:
Function Called by the eqs2lavaan Function
Description
Returns a list of extracted information from the EQS .out file.
Usage
out2lavaan(eqs)
Arguments
eqs
Specific path location of an EQS .out file. If this file is in your R directory, only the title will be necessary, otherwise a path location will also be needed.
Value
A list of the covariance matrix and descriptive statistics extracted from the EQS .out file supplied.
Details
This is a function that is referenced mainly by eqs2lavaan, however it can be used in a standalone format as well.
References
Bentler, P. M. (2008). EQS Program Manual. Encino, CA: Multivariate Software Inc.
Yves Rosseel (2012). lavaan: An R Package for Structural Equation Modeling. Journal of Statistical Software, 48(2), 1-36. URL http://www.jstatsoft.org/v48/i02/.
# EQS required to get a necessary .out file# Run for62.eqs from the EQS examples and save .out to R directory location## Not run: out2lavaan("for62.out")