eqsCorr:
Translate Covariance Matrix in EQS Output to a Correlation Matrix in R
Description
The EQS .out file contains all the necessary information to return a correlation matrix. This function allows you to extract the necessary info and save the correlation matrix for your own use in R.
Usage
eqsCorr(eqs)
Arguments
eqs
A valid unedited .out file from EQS output.
Value
A correlation matrix.
References
Bentler, P. M. (2008). EQS Program Manual. Encino, CA: Multivariate Software Inc.
Yves Rosseel (2012). lavaan: An R Package for Structural Equation Modeling. Journal of Statistical Software, 48(2), 1-36. URL http://www.jstatsoft.org/v48/i02/.